Documentation
¶
Overview ¶
Package env provides environment variable utilities for Buffalo. This package replaces the github.com/gobuffalo/envy dependency.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Get ¶
Get returns the value of the environment variable named by key. If the variable is not set or is empty, it returns the fallback value.
func GoPath ¶
func GoPath() string
GoPath returns the GOPATH environment variable. If GOPATH is not set, it returns the default GOPATH: $HOME/go
func Load ¶
Load loads .env file(s) into environment. If no filenames are provided, it loads the .env file in the current directory.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.